@@ -8,7 +8,7 @@ import json
 
 from apiclient.discovery import build
 
-from util.vidinfo import VidInfo
+from .util import VidInfo
 
 
 class PyYtData:
@@ -24,6 +24,7 @@ class PyYtData:
         self.type = type
 
     def get_videoinfo(self):
+        """Returns a list with has objects of VidInfo class"""
         rslt = []
 
         for i in range(self.maxlen):
